@@ -137,7 +137,7 @@ class MatPlotLibBase(QWidget):
         self._pending_draw = None
         self._pending_artists_draw = None
         self._other_draw_events = []
-        self._draw_timer = QTimer()
+        self._draw_timer = QTimer(self)
         self._draw_timer.timeout.connect(self._do_draw_events)
         self._draw_timer.start(20)
         self._zoom_skew = None
@@ -708,7 +708,7 @@ class MatPlotLibBase(QWidget):
                     self._axes.draw_artist(a)
                 self._canvas.update()
             self._pending_artists_draw = _update
-    
+        
     def _do_draw_events(self):
         if self._pending_draw is not None:
             self._pending_draw()
@@ -843,6 +843,12 @@ class MatPlotLibBase(QWidget):
                 height = max(height, next_height)
             self._cached_label_width_height = width, height
         return self._cached_label_width_height
+
+    def _create_new_axes(self, nx=1, ny=1) -> LocatableAxes:
+        axes = LocatableAxes(self._figure, self._divider.get_position())
+        axes.set_axes_locator(self._divider.new_locator(nx=nx, ny=ny))
+        self._figure.add_axes(axes)
+        return axes
     
     @staticmethod
     def _create_secondary_xy_axes(figure, divider, nx=1, ny=1, visible=False, z_order=1):
